@@ -3,7 +3,7 @@ import os
 import six
 import json
 import django
-from .. import views
+from .. import views, feeds
 from django.db import models
 from .. import models as bmodels
 from django.conf import settings
@@ -37,6 +37,13 @@ class MockDetailView(views.BuildableDetailView):
     template_name = 'detailview.html'
 
 
+class MockRSSFeed(feeds.BuildableFeed):
+    link = '/latest.xml'
+
+    def items(self):
+        return MockObject.objects.all()
+
+
 class JSONResponseMixin(object):
 
     def render_to_response(self, context, **response_kwargs):
@@ -152,6 +159,14 @@ class BakeryTest(TestCase):
         )
         os.remove(build_path)
 
+    def test_rss_feed(self):
+        f = MockRSSFeed()
+        f.build_method
+        f.build_queryset()
+        build_path = os.path.join(settings.BUILD_DIR, 'feed.xml')
+        self.assertTrue(os.path.exists(build_path))
+        os.remove(build_path)
+
     def test_build_cmd(self):
         call_command("build", **{'skip_media': True, 'verbosity': 3})
         call_command("build", **{'skip_static': True, 'verbosity': 3})
